@@ -20,7 +20,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 
 #include "cdrom.h"
 #include "gnome-cd.h"
@@ -404,7 +404,7 @@ static void
 cdrom_update_cd (GnomeCDRom *cdrom)
 
 {
-	g_error ("cdrom_update_cd not implmented");
+	g_error ("cdrom_update_cd not implemented");
 }
 
 static void
@@ -803,7 +803,7 @@ timeout_update_cd (gpointer data)
 		if (priv->update != GNOME_CDROM_UPDATE_NEVER)
 			gnome_cdrom_status_changed (GNOME_CDROM (cdrom), priv->recent_status);
 
-		g_free (status);
+		//g_free (status);
 
 	} else {
 		if (gnome_cdrom_status_equal (status, priv->recent_status)) {
